@@ -1,7 +1,7 @@
 package Finance::BTCIndo;
 
 our $DATE = '2017-05-31'; # DATE
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use 5.010001;
 use strict;
@@ -66,8 +66,9 @@ sub tapi {
 
     my $encoded_form = join(
         "&",
-        map { $self->{_urienc}->encode($_) . "=" .
-                  $self->{_urienc}->encode($form->{$_}) } sort keys(%$form),
+        map { $self->{_urienc}->encode($_ // ''). "=" .
+                  $self->{_urienc}->encode($form->{$_} // '') }
+            sort keys(%$form),
     );
 
     my $options = {
@@ -89,6 +90,8 @@ sub tapi {
     my $decoded;
     eval { $decoded = $self->{_json}->decode($res->{content}) };
     die "Can't decode response from $url: $@" if $@;
+    die "API response not a hash: $decoded" unless ref $decoded eq 'HASH';
+    die "API response is not success: $decoded->{error}" unless $decoded->{success};
     $decoded;
 }
 
@@ -126,7 +129,7 @@ sub get_info {
 
 sub get_tx_history {
     my ($self, %args) = @_;
-    $self->tapi("TransHistory");
+    $self->tapi("transHistory");
 }
 
 sub get_trade_history {
@@ -198,7 +201,7 @@ Finance::BTCIndo - Trade with bitcoin.co.id (VIP) using Perl
 
 =head1 VERSION
 
-This document describes version 0.001 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-05-31.
+This document describes version 0.002 of Finance::BTCIndo (from Perl distribution Finance-BTCIndo), released on 2017-05-31.
 
 =head1 SYNOPSIS
 
@@ -361,7 +364,7 @@ Arguments:
 =head2 get_tx_history
 
 This method give information about history of deposit and withdraw. The API
-method name is C<TransHistory>.
+method name is C<transHistory>.
 
 Arguments:
 
